@@ -574,6 +574,7 @@ typedef enum {
  * @DND_TARGET_TYPE_TEXT_PLAIN: text/plain
  * @DND_TARGET_TYPE_STRING: STRING
  * @DND_TARGET_TYPE_TEXT_PLAIN_UTF8: text/plain;charser=utf-8
+ * @E_DND_TARGET_TYPE_TEXT_X_MOZ_URL: text/x-moz-url ; Since:3.52
  *
  * Drag and drop targets supported by EContentEditor.
  *
@@ -586,7 +587,8 @@ typedef enum {
 	E_DND_TARGET_TYPE_UTF8_STRING,
 	E_DND_TARGET_TYPE_TEXT_PLAIN,
 	E_DND_TARGET_TYPE_STRING,
-	E_DND_TARGET_TYPE_TEXT_PLAIN_UTF8
+	E_DND_TARGET_TYPE_TEXT_PLAIN_UTF8,
+	E_DND_TARGET_TYPE_TEXT_X_MOZ_URL
 } EDnDTargetType;
 
 /**
@@ -651,16 +653,27 @@ typedef enum {
  * @E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS: enable composer quirks to post-process the text
  * @E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL: whether new lines in the text are significant,
  *    aka whether they work the same as the &lt;br&gt; elements. Since: 3.48
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_INLINE: this flag is used only together with %E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT,
+ *    and it converts links in a way that it shows href beside the text link, like: "label &lt;href&gt;". Since: 3.52
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE: this flag is used only together with %E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT,
+ *    and it converts links in a way that it shows href as reference to the end of the text, like: "label [1] ...... [1] label href". Since: 3.52
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE_WITHOUT_LABEL: this flag is used only together with %E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT,
+ *    and it converts links in a way that it shows href as reference to the end of the text without label, like: "label [1] ...... [1] href". Since: 3.52
  *
- * Flags used in e_markdown_util_html_to_text().
+ * Flags used in e_markdown_util_html_to_text(). The %E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_INLINE,
+ * %E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE and %E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE_WITHOUT_LABEL
+ * are mutually exclusive and are used only together with the %E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT flag.
  *
  * Since: 3.44
  **/
 typedef enum { /*< flags >*/
-	E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE		= 0,
-	E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT		= 1 << 0,
-	E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS	= 1 << 1,
-	E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL	= 1 << 2
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE				= 0,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT				= 1 << 0,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS			= 1 << 1,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL			= 1 << 2,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_INLINE			= 1 << 3,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE			= 1 << 4,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE_WITHOUT_LABEL	= 1 << 5
 } EMarkdownHTMLToTextFlags;
 
 /**
@@ -683,6 +696,77 @@ typedef enum {
 	E_TOOLBAR_ICON_SIZE_LARGE	= 2
 } EToolbarIconSize;
 
+typedef enum {
+	E_PREFER_SYMBOLIC_ICONS_NO	= 0,
+	E_PREFER_SYMBOLIC_ICONS_YES	= 1,
+	E_PREFER_SYMBOLIC_ICONS_AUTO	= 2
+} EPreferSymbolicIcons;
+
+/**
+ * EHTMLLinkToText:
+ * @E_HTML_LINK_TO_TEXT_NONE: do not store href in the plain text
+ * @E_HTML_LINK_TO_TEXT_INLINE: show href beside the text link, like: "label &lt;href&gt;"
+ * @E_HTML_LINK_TO_TEXT_REFERENCE: show href as reference to the end of the text, like: "label [1] ...... [1] label href"
+ * @E_HTML_LINK_TO_TEXT_REFERENCE_WITHOUT_LABEL: show href as reference to the end of the text without label, like: "label [1] ...... [1] href"
+ *
+ * How to convert links from HTML to plain text.
+ *
+ * Since: 3.52
+ **/
+typedef enum {
+	E_HTML_LINK_TO_TEXT_NONE = 0,
+	E_HTML_LINK_TO_TEXT_INLINE = 1,
+	E_HTML_LINK_TO_TEXT_REFERENCE = 2,
+	E_HTML_LINK_TO_TEXT_REFERENCE_WITHOUT_LABEL = 3
+} EHTMLLinkToText;
+
+/**
+ * EUIElementKind:
+ * @E_UI_ELEMENT_KIND_UNKNOWN: the kind is not known; used to indicate an error
+ * @E_UI_ELEMENT_KIND_ROOT: a root, aka toplevel, element; it contains elements for headerbar, toolbar and menu usually
+ * @E_UI_ELEMENT_KIND_HEADERBAR: a headerbar element
+ * @E_UI_ELEMENT_KIND_TOOLBAR: a toolbar element
+ * @E_UI_ELEMENT_KIND_MENU: a menu element
+ * @E_UI_ELEMENT_KIND_SUBMENU: a submenu of a menu element
+ * @E_UI_ELEMENT_KIND_PLACEHOLDER: a placeholder, into which can be added other elements
+ * @E_UI_ELEMENT_KIND_SEPARATOR: a separator element
+ * @E_UI_ELEMENT_KIND_START: a list of items to be packed at the start of a headerbar
+ * @E_UI_ELEMENT_KIND_END: a list of items to be packed at the end of a headerbar
+ * @E_UI_ELEMENT_KIND_ITEM: an item
+ *
+ * The UI element kinds. Depending on the kind, only respective functions can be
+ * called for the element.
+ *
+ * Since: 3.56
+ **/
+typedef enum _EUIElementKind {
+	E_UI_ELEMENT_KIND_UNKNOWN	= 0,
+	E_UI_ELEMENT_KIND_ROOT		= 1 << 0,
+	E_UI_ELEMENT_KIND_HEADERBAR	= 1 << 1,
+	E_UI_ELEMENT_KIND_TOOLBAR	= 1 << 2,
+	E_UI_ELEMENT_KIND_MENU		= 1 << 3,
+	E_UI_ELEMENT_KIND_SUBMENU	= 1 << 4,
+	E_UI_ELEMENT_KIND_PLACEHOLDER	= 1 << 5,
+	E_UI_ELEMENT_KIND_SEPARATOR	= 1 << 6,
+	E_UI_ELEMENT_KIND_START		= 1 << 7,
+	E_UI_ELEMENT_KIND_END		= 1 << 8,
+	E_UI_ELEMENT_KIND_ITEM		= 1 << 9
+} EUIElementKind;
+
+/**
+ * EUIParserExportFlags:
+ * @E_UI_PARSER_EXPORT_FLAG_NONE: no flag set
+ * @E_UI_PARSER_EXPORT_FLAG_INDENT: indent the output; when not set a single line of text is exported
+ *
+ * Set of flags to influence output of the e_ui_parser_export().
+ *
+ * Since: 3.56
+ **/
+typedef enum _EUIParserExportFlags {  /*< flags >*/
+	E_UI_PARSER_EXPORT_FLAG_NONE	= 0,
+	E_UI_PARSER_EXPORT_FLAG_INDENT	= 1 << 0
+} EUIParserExportFlags;
+
 G_END_DECLS
 
 #endif /* E_UTIL_ENUMS_H */
